melos library

Classes

BootstrapCommandConfigs
Configurations for melos bootstrap.
Changelog
CleanCommandConfigs
Configurations for melos clean.
ExecOptions
GlobalOptions
Global options that apply to all Melos commands.
IDEConfigs
IDE-specific configurations.
IdeWorkspace
IntelliJConfig
IntelliJ-specific configurations
ManualVersionChange
Melos
MelosLogger
CLI logger that encapsulates Melos log formatting conventions.
MelosWorkspace
A representation of a workspace.
MelosWorkspaceConfig
Package
PackageFilters
PackageMap
PubClientConfig
HTTP retry configuration for talking to pub (or alternate registries).
Script
Scripts
VersionCommandConfigs
Configurations for melos version.

Enums

ListOutputKind
PackageType
Enum representing what type of package this is.
ProcessStdio
Controls how the standard streams of a script's child process are wired to melos's own process.
SemverReleaseType
Indicates the semver release type this commit message creates.
VersioningMode
The mode in which packages in the workspace are versioned.

Exceptions / Errors

BootstrapException
An exception for when pub get for a package failed.
CancelledException
FixedVersioningException
InvalidPackageFiltersException
IOException
MelosConfigException
Thrown when the melos section of the root pubspec.yaml configuration is malformed.
MelosException
A base class for all melos exceptions.
NoPackageFoundScriptException
NoScriptException
PackageNotFoundException
ScriptException
ScriptNotFoundException